=======================
mdaviz: MDA Data Viewer
=======================



Key Features
============

* Visualize MDA data (currently supports 1-D plots)
* Basic mathematical information and cursor utilities
* Fitting functionality coming soon

Documentation
=============

.. icons: https://fonts.google.com/icons
.. grid:: 3

    .. grid-item-card:: :material-regular:`summarize;3em` User Guide
      :link: user_guide
      :link-type: doc

    .. grid-item-card:: :material-regular:`install_desktop;3em` Install
      :link: install
      :link-type: doc

    .. grid-item-card:: :material-regular:`api;3em` API
      :link: api
      :link-type: doc


.. figure:: _static/mdaviz_gui.png
   :alt: fig.mdaviz_gui
   :width: 100%
   :align: center
   :figclass: align-center
   :figwidth: 100%

   Screenshot of the mdaviz GUI displaying sample data.

.. toctree::
   :maxdepth: 1
   :glob:
   :caption: Contents:
   :hidden:

   user_guide
   install
   api
   changes
   license

About
=====

:home: https://bcda-aps.github.io/mdaviz/
:bug tracker: https://github.com/BCDA-APS/mdaviz/issues
:source: https://github.com/BCDA-APS/mdaviz
:license: :ref:`license`
:full version: |release|
:published: |today|
:revisions: :ref:`History of code changes <changes>`
:index: :ref:`genindex`
:module: :ref:`modindex`
:search: :ref:`search`

Acknowledgements
================

"This product includes software produced by UChicago Argonne, LLC
under Contract No. DE-AC02-06CH11357 with the Department of Energy."
